import { NextRequest, NextResponse } from 'next/server'
import { fal } from "@fal-ai/client"

if (!process.env.FAL_AI_KEY) {
  throw new Error('FAL_AI_KEY is not configured in environment variables')
}

// Configure fal client server-side only
fal.config({
  credentials: process.env.FAL_AI_KEY
})

export async function POST(req: NextRequest): Promise<NextResponse> {
  try {
    const { prompt } = await req.json()

    if (!prompt) {
      return NextResponse.json(
        { error: 'Prompt is required' },
        { status: 400 }
      )
    }

    console.log('Attempting Fal.ai request with prompt:', prompt)

    const result = await fal.subscribe("fal-ai/flux-pro/v1.1", {
      input: {
        prompt
      },
      logs: true,
      onQueueUpdate: (update) => {
        if (update.status === "IN_PROGRESS") {
          console.log('Generation progress:', update.logs.map((log) => log.message))
        }
      },
    })

    console.log('Fal.ai response received:', result)
    return NextResponse.json(result)
  } catch (error) {
    console.error('Image generation error:', error)
    return NextResponse.json(
      { error: error instanceof Error ? error.message : 'Failed to generate image' },
      { status: 500 }
    )
  }
}

export const dynamic = 'force-dynamic'
