import { NextRequest, NextResponse } from 'next/server';

export async function GET(req: NextRequest, { params }: { params: { cid?: string } }) {
  const { cid } = params;

  if (!cid) {
    return NextResponse.json({ error: 'CID is required' }, { status: 400 });
  }

  const pinataUrl = `https://${process.env.PINATA_GATEWAY}/ipfs/${cid}`;

  try {
    const response = await fetch(pinataUrl);

    if (!response.ok) {
      return NextResponse.json({ error: 'Failed to fetch from Pinata' }, { status: response.status });
    }

    const contentType = response.headers.get('content-type') || 'application/octet-stream';
    const buffer = await response.arrayBuffer();

    return new NextResponse(buffer, {
      status: 200,
      headers: { 'Content-Type': contentType },
    });
  } catch (error) {
    console.error('Error fetching from Pinata:', error);
    return NextResponse.json({ error: 'Server error' }, { status: 500 });
  }
}
