import { NextRequest, NextResponse } from 'next/server';

import { processTweet, verifySignatureInTweet } from '../../../utils/verifyTweet';
import { extractData } from '../../../utils/tweetMessage';

export async function POST(req: NextRequest): Promise<NextResponse> {
  try {
    const { tweetUrl, secret } = await req.json();

    if(secret !== process.env.VERIFY_TWEET_SECRET) {
      return NextResponse.json(
        { error: 'Access denied' },
        { status: 401 }
      )
    }

    const url = `https://publish.twitter.com/oembed?url=${tweetUrl}&maxwidth=600`;

    const response = await fetch(url);
    const data = await response.json();

    const { handle, txSignature, memeUrl } = extractData(data.html);

    if (!handle || !txSignature) {
      return NextResponse.json(
        { error: 'Could not extract tweet data' },
        { status: 500 }
      )
    }

    const isSigVerified = await verifySignatureInTweet(txSignature);
    const isHandleCorrect = handle === process.env.NEXT_PUBLIC_TWITTER_HANDLE;

    // TODO: Verify dynamic page URL in tweet
    const isVerified = isSigVerified && isHandleCorrect;
    if (!isVerified) {
      throw new Error('Tweet is not valid');
    }

    // Verify and store valid tweet
    const result = await processTweet(txSignature, memeUrl);

    return NextResponse.json(result)
  } catch (error) {
    console.error('Error while verifying tweet:', error)
    return NextResponse.json(
      { error: error.message },
      { status: 500 }
    )
  }
}
