'use client'

import React, { useState } from 'react'

const TweetUrlForm: React.FC<{secret: string}> = ({secret}) => {
  const [inputText, setInputText] = useState<string>('')

  const [isSubmitted, setIsSubmitted] = useState(false);
  const [loading, setLoading] = useState(false);
  const [submitError, setSubmitError] = useState<string | null>(null);
  const [escrow, setEscrow] = useState('');

  const handleSubmit = async (): Promise<void> => {
    try {
      setLoading(true)
      const response = await fetch('/api/tweet', {
        method: 'POST',
        headers: {
          'Content-Type': 'application/json',
        },
        body: JSON.stringify({ tweetUrl: inputText, secret }),
      })

      const parsedResponse = await response.json();

      if (!response.ok) {
        setSubmitError(parsedResponse.error);
        throw new Error(`Failed to submit tweet: ${response.statusText}`);
      }

      if (parsedResponse.data && parsedResponse.data.escrow) {
        setEscrow(parsedResponse.data.escrow);
      }

    } catch (error) {
      setSubmitError(error.message);
      console.error('Failed to submit tweet:', error);
    } finally {
      setIsSubmitted(true);
      setLoading(false);
      setInputText('');
    }
  }

  return (
    <div className="bg-gray-800/50 backdrop-blur-lg rounded-2xl shadow-xl border border-gray-700/50 mb-8 mx-auto my-10">
      <div className="p-6">

        <div className="space-y-4">
          {isSubmitted ? submitError ?  <p className='text-red-500'>Submission failed: {submitError}</p> : <p className='text-green-500'>Tweet submitted!</p> : <></>}
          {escrow && <p className='text-green-500'>Lock created successfully: {escrow}</p>}
          <textarea
            value={inputText}
            onChange={(e) => setInputText(e.target.value)}
            placeholder="Enter the tweet URL here..."
            className="w-full bg-gray-900/50 text-gray-100 border border-gray-700 rounded-xl p-4
                     placeholder-gray-500 focus:border-green-500 focus:ring-2 focus:ring-green-500/20
                     focus:outline-none min-h-[120px] transition-all duration-200
                     disabled:opacity-50 disabled:cursor-not-allowed"
            rows={4}
          />
          <button
            onClick={handleSubmit}
            className="w-full bg-gradient-to-r from-green-500 to-emerald-500 hover:from-green-600
                     hover:to-emerald-600 text-white font-semibold py-4 px-6 rounded-xl
                     transition-all duration-200 shadow-lg hover:shadow-green-500/25
                     disabled:opacity-50 disabled:cursor-not-allowed disabled:hover:shadow-none"
          >
            {loading ? 'Submitting...' : 'Submit' }
          </button>
        </div>

      </div>
    </div>
  )
}

export default TweetUrlForm