//  Reference: https://github.com/jup-ag/jup-lock/blob/main/tests/locker_utils/index.ts

import {
  AccountMeta,
  Connection,
  PublicKey,
  TransactionInstruction,
} from '@solana/web3.js';
import {
  addExtraAccountsToInstruction,
  getMint,
  getTransferHook,
  TOKEN_2022_PROGRAM_ID,
} from '@solana/spl-token';

export class TokenExtensionUtil {
  public static async getExtraAccountMetasForTransferHook(
    connection: Connection,
    tokenMint: PublicKey,
    source: PublicKey,
    destination: PublicKey,
    owner: PublicKey,
    tokenProgram: PublicKey
  ): Promise<AccountMeta[] | undefined> {
    let mint = await getMint(connection, tokenMint, 'confirmed', tokenProgram);
    const transferHook = getTransferHook(mint);

    if (!transferHook) return undefined;

    const instruction = new TransactionInstruction({
      programId: TOKEN_2022_PROGRAM_ID,
      keys: [
        { pubkey: source, isSigner: false, isWritable: false },
        {
          pubkey: tokenMint,
          isSigner: false,
          isWritable: false,
        },
        { pubkey: destination, isSigner: false, isWritable: false },
        { pubkey: owner, isSigner: false, isWritable: false },
        { pubkey: owner, isSigner: false, isWritable: false },
      ],
    });

    // Note:
    await addExtraAccountsToInstruction(
      connection,
      instruction,
      tokenMint,
      'confirmed',
      transferHook.programId,
    );

    const extraAccountMetas = instruction.keys.slice(5);
    return extraAccountMetas.length > 0 ? extraAccountMetas : undefined;
  }
}
