export interface OllamaGenerationResult {
  textResponse?: string
  error?: string
}

export async function generateWithOllama(prompt: string): Promise<OllamaGenerationResult> {
  try {
    const response = await fetch('/api/ollama', {
      method: 'POST',
      headers: {
        'Content-Type': 'application/json',
      },
      body: JSON.stringify({ prompt }),
    })

    if (!response.ok) {
      throw new Error('Failed to generate text')
    }

    const data = await response.json()
    console.log('Raw Ollama response:', data)
    
    if (data.response) {
      return { textResponse: data.response }
    } else {
      console.error('Unexpected response structure:', data)
      throw new Error('Invalid response format from Ollama API')
    }
  } catch (error) {
    console.error('Generation error:', error)
    return { 
      error: error instanceof Error ? error.message : 'Generation failed'
    }
  }
}
